--- layout: base title: What's New navbar_active: whats-new relative_path: ../ --- {% capture jumbotron_h1 %} What's New{% endcapture %} {% capture jumbotron_p %}What's New with {{ site.forkawesome.name }} {{ site.forkawesome.minor_version }}{% endcapture %} {% include jumbotron.html %} {% include stripe-social.html %}

{{ site.forkawesome.name }} is now a community effort based on {{ site.fontawesome.name }} {{ site.fontawesome.version }} by {{ site.fontawesome.author.name }}.
We {{ site.fontawesome.name }} but here's why we forked it into {{ site.forkawesome.name }} {{ site.forkawesome.minor_version }}. Want to help contribute?

#### PR freeze

Since Oct 22, 2016, Font Awesome has frozen all pull requests proposing new icons. With {{ site.forkawesome.name }}, we are welcoming all your pull requests.

#### Font Awesome 5.0

Fort Awesome has run a very successful kickstarter campaign and completely redesigned Font Awesome in this new version 5.0. Fork Awesome plans to keep the old look alive.

#### Distributed community

We believe in distributed open source design projects, where all contributions are included and credited. So join our community.
{% include icons/new.html %} {% include new-upgrading.html %}